<?php
/*
Plugin Name: Top (3) produkty
Description: Wtyczka pozwala na dodanie pozycji w rankingu, wyświetlenie wpisu jako wyróżnionej pozycji oraz utworzenie widgetu z Top (3) produktami.
Author: DKiT
Version: 1.0.3
*/

/** Image thumbnail size */
add_image_size('top-3-thumbnail', 120, 200, true);

/** Add custom meta boxes */
function custom_meta_box_markup($object)
{
    wp_nonce_field(basename(__FILE__), 'meta-box-nonce');
    ?>
        <p>
            <label for="meta-ranking-position">Pozycja w rankingu</label>
            <input id ="meta-ranking-position" name="meta-ranking-position" type="number" min="1" value="<?php echo get_post_meta($object->ID, 'meta-ranking-position', true); ?>">
        </p>
        <p>
            <?php
                $checkbox_value = get_post_meta($object->ID, 'meta-first-product', true);

                if($checkbox_value == "")
                {
                    ?>
                        <input id="meta-first-product" name="meta-first-product" type="checkbox" value="true">
                    <?php
                }
                else if($checkbox_value == "true")
                {
                    ?>
                        <input id="meta-first-product" name="meta-first-product" type="checkbox" value="true" checked>
                    <?php
                }
            ?>
            <label for="meta-first-product">Wyróżnij</label>
        </p>
    <?php
}

function add_custom_meta_box()
{
    add_meta_box(
        'top-3-meta-box',
        'Top (3) produkty',
        'custom_meta_box_markup',
        'custom_post_type' == '',
        'side',
        'high',
        null
    );
}
add_action('add_meta_boxes', 'add_custom_meta_box');

function save_custom_meta_box($post_id, $post, $update)
{
    if (!isset($_POST["meta-box-nonce"]) || !wp_verify_nonce($_POST["meta-box-nonce"], basename(__FILE__)))
        return $post_id;

    if(!current_user_can("edit_post", $post_id))
        return $post_id;

    if(defined("DOING_AUTOSAVE") && DOING_AUTOSAVE)
        return $post_id;

    $meta_ranking_position_value = "";
    $meta_first_product_value = "";

    if(isset($_POST["meta-ranking-position"]))
    {
        $meta_ranking_position_value = $_POST["meta-ranking-position"];
    }
    update_post_meta($post_id, "meta-ranking-position", $meta_ranking_position_value);

    if(isset($_POST["meta-first-product"]))
    {
        $meta_first_product_value = $_POST["meta-first-product"];
    }
    update_post_meta($post_id, "meta-first-product", $meta_first_product_value);
}
add_action("save_post", "save_custom_meta_box", 10, 3);



/** Widget Top (3) produkty*/
class DKiT_Top_3_produkty extends WP_Widget {

    function __construct() {

        parent::__construct(
            'dkit-top-3-widget',  // Base ID
            'DKiT: Top (3) produkty',  // Name
            array( 'description' => __( 'Wyświetla Top (3) produkty', 'dkit' ), )  // Description
        );

        add_action( 'widgets_init', function() {
            register_widget( 'DKiT_Top_3_produkty' );
        });

    }

    public function widget( $args, $instance ) {
        echo $args['before_widget'];
            if ( ! empty( $instance['title'] ) ) {
                echo '<h3 class="top-3-widget-title widget-title">' . '<span class="top-3-widget-title-1">' . $instance['title'] . '</span>' . ' <span class="top-3-widget-title-2">' . $instance['title_2'] . '</span>' . ' <span class="top-3-widget-title-3">' . $instance['title_3'] . '</span></h3>';
            }
            ?>

            <?php
                $count = 0;

                $new_category_ID = $instance['category_ID'];
                $new_quantity = $instance['quantity'];
                $new_order = $instance['order'];
                $new_link_more = $instance['link_more'];
                $new_post_type = $instance['post_type'];

                if (!empty($new_post_type)) {
                    $new_category_ID = '';
                }

                $widget_args = array(
                    'post_type'=> $new_post_type,
                    'meta_key' => 'meta-ranking-position',
                    'orderby' => 'meta_value_num',
                    'order' => $new_order,
                    'cat' => $new_category_ID,
                    'posts_per_page' => $new_quantity,
                );

                $widget_query = new WP_Query($widget_args);
            ?>

            <ul class="top-3">
                <?php while($widget_query->have_posts()) : $widget_query->the_post(); $count++; ?>
                    <?php $post_title = get_the_title(); ?>
                    <li id="post-<?php the_ID(); ?>" <?php post_class('post'); ?>>
                        <?php
                            $post = get_the_ID();
                            $ranking_position = get_post_meta($post, 'meta-ranking-position', true);
                            $is_first = get_post_meta($post, 'meta-first-product', true);
                        ?>
                        <div class="top-3-item<?php echo ($is_first == true) ? ' top-3-item-first' : ''; ?>">
                            <div class="top-3-header">
                                <header>
                                    <h4>
                                        <a href="<?php the_permalink(); ?>" title="<?php echo wp_strip_all_tags($post_title); ?>">
                                            <span class="top-3-number"><?php echo $ranking_position .'.'; ?></span>
                                            <?php echo $post_title; ?>
                                        </a>
                                    </h4>
                                </header>
                            </div>
                            <div class="top-3-content">
                                <div class="top-3-img">
                                    <a href="<?php the_permalink(); ?>" title="<?php echo wp_strip_all_tags($post_title); ?>">
                                        <?php if ( has_post_thumbnail() ) : the_post_thumbnail('top-3-thumbnail'); endif; ?>
                                    </a>
                                </div>
                                <a href="<?php the_permalink(); ?>" title="<?php echo $new_link_more; ?>" class="top-3-link-more"><?php echo $new_link_more; ?></a>
                            </div>
                        </div>
                    </li>
                <?php endwhile; ?>
            </ul>
            <?php wp_reset_postdata(); ?>
        <?php echo $args['after_widget'];
    }

    public function form( $instance ) {
        $title = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( '', 'dkit' );
        $title_2 = ! empty( $instance['title_2'] ) ? $instance['title_2'] : esc_html__( '', 'dkit' );
        $title_3 = ! empty( $instance['title_3'] ) ? $instance['title_3'] : esc_html__( '', 'dkit' );
        $link_more = ! empty( $instance['link_more'] ) ? $instance['link_more'] : esc_html__( 'Czytaj więcej', 'dkit' );
        $quantity = ! empty( $instance['quantity'] ) ? $instance['quantity'] : esc_html__( '3', 'dkit' );
        $order = ! empty( $instance['order'] ) ? $instance['order'] : esc_html__( '', 'dkit' );
        $category_ID = ! empty( $instance['category_ID'] ) ? $instance['category_ID'] : esc_html__( '1', 'dkit' );
        $post_type = ! empty( $instance['post_type'] ) ? $instance['post_type'] : esc_html__( '', 'dkit' );
    ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php echo esc_html__( 'Tytuł:', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title_2' ) ); ?>"><?php echo esc_html__( 'Tytuł 2:', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title_2' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title_2' ) ); ?>" type="text" value="<?php echo esc_attr( $title_2 ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title_3' ) ); ?>"><?php echo esc_html__( 'Tytuł 3:', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title_3' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title_3' ) ); ?>" type="text" value="<?php echo esc_attr( $title_3 ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'link_more' ) ); ?>"><?php echo esc_html__( 'Przycisk "Czytaj więcej":', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'link_more' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'link_more' ) ); ?>" type="text" value="<?php echo esc_attr( $link_more ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'quantity' ) ); ?>"><?php echo esc_html__( 'Ilość postów:', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'quantity' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'quantity' ) ); ?>" type="number" min="1" value="<?php echo esc_attr( $quantity ); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('order'); ?>"><?php echo esc_html__( 'Kolejność:', 'dkit' ); ?>
                <select class='widefat' id="<?php echo $this->get_field_id('order'); ?>" name="<?php echo $this->get_field_name('order'); ?>" type="text">
                    <option value='ASC'<?php echo ($order=='ASC')?'selected':''; ?>>
                        <?php echo esc_html__( 'Rosnąco', 'dkit' ); ?>
                    </option>
                    <option value='DESC'<?php echo ($order=='DESC')?'selected':''; ?>>
                        <?php echo esc_html__( 'Malejąco', 'dkit' ); ?>
                    </option>
                </select>
            </label>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'category_ID' ) ); ?>"><?php echo esc_html__( 'ID kategorii rankingu:', 'dkit' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'category_ID' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'category_ID' ) ); ?>" type="number" min="1" value="<?php echo esc_attr( $category_ID ); ?>">
        </p>

        <?php
            $args = array(
                'public' => true,
                '_builtin' => false,
            );

            $custom_post_types = get_post_types( $args );
        ?>

        <p>
            <label for="<?php echo $this->get_field_id('post_type'); ?>"><?php echo esc_html__( 'Rodzaj postów:', 'dkit' ); ?>
                <select class='widefat' id="<?php echo $this->get_field_id('post_type'); ?>" name="<?php echo $this->get_field_name('post_type'); ?>" type="text">
                    <option value=''<?php echo ($post_type=='')?'selected':''; ?>>
                        <?php echo esc_html__( '', 'dkit' ); ?>
                    </option>

                    <?php foreach ($custom_post_types as $custom_post_type) : ?>

                        <?php $post_type_obj = get_post_type_object( $custom_post_type ); ?>

                        <option value='<?php echo $custom_post_type ?>'<?php echo ($post_type==$custom_post_type)?'selected':''; ?>>
                            <?php echo esc_html__( $post_type_obj->labels->name, 'dkit' ); ?>
                        </option>

                    <?php endforeach; ?>
                </select>
            </label>
        </p>
    <?php }

    public function update( $new_instance, $old_instance ) {

        $instance = array();

        $instance['title'] = ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
        $instance['title_2'] = ( !empty( $new_instance['title_2'] ) ) ? strip_tags( $new_instance['title_2'] ) : '';
        $instance['title_3'] = ( !empty( $new_instance['title_3'] ) ) ? strip_tags( $new_instance['title_3'] ) : '';
        $instance['link_more'] = ( !empty( $new_instance['link_more'] ) ) ? strip_tags( $new_instance['link_more'] ) : '';
        $instance['quantity'] = ( !empty( $new_instance['quantity'] ) ) ? strip_tags( $new_instance['quantity'] ) : '';
        $instance['order'] = ( !empty( $new_instance['order'] ) ) ? strip_tags( $new_instance['order'] ) : '';
        $instance['category_ID'] = ( !empty( $new_instance['category_ID'] ) ) ? strip_tags( $new_instance['category_ID'] ) : '';
        $instance['post_type'] = ( !empty( $new_instance['post_type'] ) ) ? strip_tags( $new_instance['post_type'] ) : '';

        return $instance;
    }

}
$dkit_Top_3_produkty = new DKiT_Top_3_produkty();